{% load poison %}
<!DOCTYPE html>
<html>
<head>
    <title>Index</title>
</head>
<body>
{% poison %}
{% if not request.GET.poison %}
<a href="?poison=1">Poisoned version.</a><br/>
{% endif %}
<p>The most merciful thing in the world, I think, is the inability of the human mind to correlate all its contents.</p>
<p>We live on a placid island of ignorance in the midst of black seas of infinity, and it was not meant that we should voyage far.</p>
<p>The sciences, each straining in its own direction, have hitherto harmed us little; but some day the piecing together of dissociated knowledge will open up such terrifying vistas of reality, and of our frightful position therein, that we shall either go mad from the revelation or flee from the deadly light into the peace and safety of a new dark age.</p>
<p>Theosophists have guessed at the awesome grandeur of the cosmic cycle wherein our world and human race form transient incidents.</p>
<p> They have hinted at strange survivals in terms which would freeze the blood if not masked by a bland optimism.</p>
<p>But it is not from them that there came the single glimpse of forbidden aeons which chills me when I think of it and maddens me when I dream of it.</p>
<p>That glimpse, like all dread glimpses of truth, flashed out from an accidental piecing together of separated things—in this case an old newspaper item and the notes of a dead professor.</p>
<p>I hope that no one else will accomplish this piecing out; certainly, if I live, I shall never knowingly supply a link in so hideous a chain.</p>
<p>I think that the professor, too, intended to keep silent regarding the part he knew, and that he would have destroyed his notes had not sudden death seized him.</p>
<p>My knowledge of the thing began in the winter of 1926–27 with the death of my grand-uncle George Gammell Angell, Professor Emeritus of Semitic Languages in Brown University, Providence, Rhode Island.</p>
<p>Professor Angell was widely known as an authority on ancient inscriptions, and had frequently been resorted to by the heads of prominent museums; so that his passing at the age of ninety-two may be recalled by many.</p>
<p>Locally, interest was intensified by the obscurity of the cause of death.</p>
<p>The professor had been stricken whilst returning from the Newport boat; falling suddenly, as witnesses said, after having been jostled by a nautical-looking negro who had come from one of the queer dark courts on the precipitous hillside which formed a short cut from the waterfront to the deceased’s home in Williams Street.</p>
<p>Physicians were unable to find any visible disorder, but concluded after perplexed debate that some obscure lesion of the heart, induced by the brisk ascent of so steep a hill by so elderly a man, was responsible for the end.</p>
<p>At the time I saw no reason to dissent from this dictum, but latterly I am inclined to wonder—and more than wonder.</p>
<p>As my grand-uncle’s heir and executor, for he died a childless widower, I was expected to go over his papers with some thoroughness; and for that purpose moved his entire set of files and boxes to my quarters in Boston.</p>
<p>Much of the material which I correlated will be later published by the American Archaeological Society, but there was one box which I found exceedingly puzzling, and which I felt much averse from shewing to other eyes.</p>
<p>It had been locked, and I did not find the key till it occurred to me to examine the personal ring which the professor carried always in his pocket.</p>
<p>Then indeed I succeeded in opening it, but when I did so seemed only to be confronted by a greater and more closely locked barrier.</p>
<p>For what could be the meaning of the queer clay bas-relief and the disjointed jottings, ramblings, and cuttings which I found?</p>
<p>Had my uncle, in his latter years, become credulous of the most superficial impostures?</p>
<p>I resolved to search out the eccentric sculptor responsible for this apparent disturbance of an old man’s peace of mind.</p>
{% endpoison %}
</p>
</body>
</html>
