AGENTS = [
  "AI2Bot",
  "Ai2Bot-Dolma",
  "Amazonbot",
  "Applebot",
  "Applebot-Extended",
  "Bytespider",
  "CCBot",
  "ChatGPT-User",
  "Claude-Web",
  "ClaudeBot",
  "Diffbot",
  "DuckAssistBot",
  "FacebookBot",
  "FriendlyCrawler",
  "GPTBot",
  "Google-Extended",
  "GoogleOther",
  "GoogleOther-Image",
  "GoogleOther-Video",
  "ICC-Crawler",
  "ISSCyberRiskCrawler",
  "ImagesiftBot",
  "Kangaroo Bot",
  "Meta-ExternalAgent",
  "Meta-ExternalFetcher",
  "OAI-SearchBot",
  "PanguBot",
  "PerplexityBot",
  "PetalBot",
  "Scrapy",
  "SemrushBot",
  "Sidetrade indexer bot",
  "Timpibot",
  "VelenPublicWebCrawler",
  "Webzio-Extended",
  "YouBot",
  "anthropic-ai",
  "cohere-ai",
  "cohere-training-data-crawler",
  "iaskspider/2.0",
  "img2dataset",
  "omgili",
  "omgilibot"
]
